@@ -16,16 +16,15 @@ usage (int status)
   if (status)
     fprintf(stderr, "Try `%s --help' for more information.\n", progname);
   else
-    printf("Usage: %s [OPTION]\n\
-Create a temporary file in a safe manner.
-\n\
--d, --directory=DIR  place temporary file in DIR\n\
--p, --prefix=STRING  set temporary file's prefix to STRING\n\
--s, --suffix=STRING  set temporary file's suffix to STRING\n\
--m, --mode=MODE      open with MODE instead of 0600\n\
--n, --name=FILE      use FILE instead of tempnam(3)\n\
-    --help           display this help and exit\n\
-    --version        output version information and exit\n", progname);
+    printf("Usage: %s [OPTION]\n\n"
+"Create a temporary file in a safe manner.\n\n"
+"-d, --directory=DIR  place temporary file in DIR\n"
+"-p, --prefix=STRING  set temporary file's prefix to STRING\n"
+"-s, --suffix=STRING  set temporary file's suffix to STRING\n"
+"-m, --mode=MODE      open with MODE instead of 0600\n"
+"-n, --name=FILE      use FILE instead of tempnam(3)\n"
+"    --help           display this help and exit\n"
+"    --version        output version information and exit\n", progname);
   exit(status);
 }
 
@@ -95,7 +94,7 @@ main (int argc, char **argv)
     case 'h':
       usage(0);
     case 'v':
-      puts("tempfile 1.0");
+      puts("tempfile " PACKAGE_VERSION);
       exit(0);
     default:
       usage(1);
